==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/lb/kotlin/inputs/ListenerDefaultActionFixedResponseArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.lb.kotlin.inputs

import com.pulumi.aws.lb.inputs.ListenerDefaultActionFixedResponseArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property contentType Content type. Valid values are `text/plain`, `text/css`, `text/html`, `application/javascript` and `application/json`.
 * The following arguments are optional:
 * @property messageBody Message body.
 * @property statusCode HTTP response code. Valid values are `2XX`, `4XX`, or `5XX`.
 */
public data class ListenerDefaultActionFixedResponseArgs(
    public val contentType: Output<String>,
    public val messageBody: Output<String>? = null,
    public val statusCode: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.aws.lb.inputs.ListenerDefaultActionFixedResponseArgs> {
    override fun toJava(): com.pulumi.aws.lb.inputs.ListenerDefaultActionFixedResponseArgs =
        com.pulumi.aws.lb.inputs.ListenerDefaultActionFixedResponseArgs.builder()
            .contentType(contentType.applyValue({ args0 -> args0 }))
            .messageBody(messageBody?.applyValue({ args0 -> args0 }))
            .statusCode(statusCode?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ListenerDefaultActionFixedResponseArgs].
 */
@PulumiTagMarker
public class ListenerDefaultActionFixedResponseArgsBuilder internal constructor() {
    private var contentType: Output<String>? = null

    private var messageBody: Output<String>? = null

    private var statusCode: Output<String>? = null

    /**
     * @param value Content type. Valid values are `text/plain`, `text/css`, `text/html`, `application/javascript` and `application/json`.
     * The following arguments are optional:
     */
    @JvmName("ywddfcdumxbllvsu")
    public suspend fun contentType(`value`: Output<String>) {
        this.contentType = value
    }

    /**
     * @param value Message body.
     */
    @JvmName("frobxnclmbjyoune")
    public suspend fun messageBody(`value`: Output<String>) {
        this.messageBody = value
    }

    /**
     * @param value HTTP response code. Valid values are `2XX`, `4XX`, or `5XX`.
     */
    @JvmName("vcjievwlxibpvjwj")
    public suspend fun statusCode(`value`: Output<String>) {
        this.statusCode = value
    }

    /**
     * @param value Content type. Valid values are `text/plain`, `text/css`, `text/html`, `application/javascript` and `application/json`.
     * The following arguments are optional:
     */
    @JvmName("ftrksvghbweqbuky")
    public suspend fun contentType(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.contentType = mapped
    }

    /**
     * @param value Message body.
     */
    @JvmName("mfamihcsixugnqqb")
    public suspend fun messageBody(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.messageBody = mapped
    }

    /**
     * @param value HTTP response code. Valid values are `2XX`, `4XX`, or `5XX`.
     */
    @JvmName("taqmunjbuhobygpc")
    public suspend fun statusCode(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.statusCode = mapped
    }

    internal fun build(): ListenerDefaultActionFixedResponseArgs =
        ListenerDefaultActionFixedResponseArgs(
            contentType = contentType ?: throw PulumiNullFieldException("contentType"),
            messageBody = messageBody,
            statusCode = statusCode,
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/lb/kotlin/inputs/ListenerDefaultActionFixedResponseArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.lb.kotlin.inputs

import com.pulumi.aws.lb.inputs.ListenerDefaultActionFixedResponseArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property contentType Content type. Valid values are `text/plain`, `text/css`, `text/html`, `application/javascript` and `application/json`.
 * The following arguments are optional:
 * @property messageBody Message body.
 * @property statusCode HTTP response code. Valid values are `2XX`, `4XX`, or `5XX`.
 */
public data class ListenerDefaultActionFixedResponseArgs(
    public val contentType: Output<String>,
    public val messageBody: Output<String>? = null,
    public val statusCode: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.aws.lb.inputs.ListenerDefaultActionFixedResponseArgs> {
    override fun toJava(): com.pulumi.aws.lb.inputs.ListenerDefaultActionFixedResponseArgs =
        com.pulumi.aws.lb.inputs.ListenerDefaultActionFixedResponseArgs.builder()
            .contentType(contentType.applyValue({ args0 -> args0 }))
            .messageBody(messageBody?.applyValue({ args0 -> args0 }))
            .statusCode(statusCode?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ListenerDefaultActionFixedResponseArgs].
 */
@PulumiTagMarker
public class ListenerDefaultActionFixedResponseArgsBuilder internal constructor() {
    private var contentType: Output<String>? = null

    private var messageBody: Output<String>? = null

    private var statusCode: Output<String>? = null

    /**
     * @param value Content type. Valid values are `text/plain`, `text/css`, `text/html`, `application/javascript` and `application/json`.
     * The following arguments are optional:
     */
    @JvmName("babrvdijjwjqtuku")
    public suspend fun contentType(`value`: Output<String>) {
        this.contentType = value
    }

    /**
     * @param value Message body.
     */
    @JvmName("wortpaiumepwiryq")
    public suspend fun messageBody(`value`: Output<String>) {
        this.messageBody = value
    }

    /**
     * @param value HTTP response code. Valid values are `2XX`, `4XX`, or `5XX`.
     */
    @JvmName("cabqofflmjxghnwg")
    public suspend fun statusCode(`value`: Output<String>) {
        this.statusCode = value
    }

    /**
     * @param value Content type. Valid values are `text/plain`, `text/css`, `text/html`, `application/javascript` and `application/json`.
     * The following arguments are optional:
     */
    @JvmName("aaugfijdxrrdkrje")
    public suspend fun contentType(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.contentType = mapped
    }

    /**
     * @param value Message body.
     */
    @JvmName("hutvaxetwhgcdnnb")
    public suspend fun messageBody(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.messageBody = mapped
    }

    /**
     * @param value HTTP response code. Valid values are `2XX`, `4XX`, or `5XX`.
     */
    @JvmName("xnnvsreqtjmfewfs")
    public suspend fun statusCode(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.statusCode = mapped
    }

    internal fun build(): ListenerDefaultActionFixedResponseArgs =
        ListenerDefaultActionFixedResponseArgs(
            contentType = contentType ?: throw PulumiNullFieldException("contentType"),
            messageBody = messageBody,
            statusCode = statusCode,
        )
}
